summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/indexschema.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexidb/indexschema.h')
-rw-r--r--kexi/kexidb/indexschema.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kexi/kexidb/indexschema.h b/kexi/kexidb/indexschema.h
index a8bec4338..60d1d7ac7 100644
--- a/kexi/kexidb/indexschema.h
+++ b/kexi/kexidb/indexschema.h
@@ -20,8 +20,8 @@
#ifndef KEXIDB_INDEX_H
#define KEXIDB_INDEX_H
-#include <qvaluelist.h>
-#include <qstring.h>
+#include <tqvaluelist.h>
+#include <tqstring.h>
#include <kexidb/fieldlist.h>
#include <kexidb/schemadata.h>
@@ -43,8 +43,8 @@ class Relationship;
class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
{
public:
- typedef QPtrList<IndexSchema> List;
- typedef QPtrListIterator<IndexSchema> ListIterator;
+ typedef TQPtrList<IndexSchema> List;
+ typedef TQPtrListIterator<IndexSchema> ListIterator;
/*! Constructs empty index schema object
that is assigned to \a table, and will be owned by this table.
@@ -56,7 +56,7 @@ class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
/*! Copy constructor. Copies all attributes from index \a idx, and
fields assigned with it but the fields are taken (by name) from
- \a parentTable, not from \a idx itself, so it's possible to copy of index
+ \a tqparentTable, not from \a idx itself, so it's possible to copy of index
for a copy of table.
To copy an index within the same table it's enough to call:
@@ -65,7 +65,7 @@ class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
\endcode
@todo All relationships should be also copied
*/
- IndexSchema(const IndexSchema& idx, TableSchema& parentTable);
+ IndexSchema(const IndexSchema& idx, TableSchema& tqparentTable);
/*! Destroys the index. Field objects are not deleted.
All Relationship objects listed in masterRelationships() list
@@ -110,7 +110,7 @@ class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
is this IndexSchem object assigned.
Note: If \a rel was detached from masterRelationships() list,
- this object now has no parent, so you need to attach it to somewhere or destruct it.
+ this object now has no tqparent, so you need to attach it to somewhere or destruct it.
*/
void detachRelationship(Relationship *rel);
@@ -118,7 +118,7 @@ class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
Auto-generated index is one-field index
that was automatically generated
for CREATE TABLE statement when the field has
- UNIQUE or PRIMARY KEY constraint enabled.
+ UNITQUE or PRIMARY KEY constraint enabled.
Any newly created IndexSchema object
has this flag set to false.
@@ -137,21 +137,21 @@ class KEXI_DB_EXPORT IndexSchema : public FieldList, public SchemaData
/*! Sets PRIMARY KEY flag. \sa isPrimary().
Note: Setting PRIMARY KEY on (true),
- UNIQUE flag will be also implicity set. */
+ UNITQUE flag will be also implicity set. */
void setPrimaryKey(bool set);
/*! \return true if this is unique index.
This can be one or multifield. */
bool isUnique() const;
- /*! Sets UNIQUE flag. \sa isUnique().
- Note: Setting UNIQUE off (false), PRIMARY KEY flag will
- be also implicity set off, because this UNIQUE
+ /*! Sets UNITQUE flag. \sa isUnique().
+ Note: Setting UNITQUE off (false), PRIMARY KEY flag will
+ be also implicity set off, because this UNITQUE
is the requirement for PRIMARY KEYS. */
void setUnique(bool set);
/*! \return String for debugging purposes. */
- virtual QString debugString();
+ virtual TQString debugString();
protected:
/*! Internal constructor for convenience.